@@ -1,10 +1,10 @@
 use 5.014;
-#package Thread::Queue::Any '1.11; # not supported by PAUSE or MetaCPAN :-(
-package Thread::Queue::Any;        # please remove if no longer needed
+#package Thread::Queue::Any '1.13'; # not supported by PAUSE or MetaCPAN :-(
+package Thread::Queue::Any;         # please remove if no longer needed
 
 # initializations
 our @ISA= qw( Thread::Queue );
-our $VERSION= '1.11';              # please remove if no longer needed
+our $VERSION= '1.13';               # please remove if no longer needed
 
 # be as verbose as possble
 use warnings;
@@ -106,7 +106,7 @@ sub import {
         push @errors, "Cannot serialize with '$serializer', already using '$SERIALIZER'"
           if $SERIALIZER and $serializer ne $SERIALIZER;
         push @errors, "Cannot serialize with '$serializer', already using freeze/thaw"
-          if !$SERIALIZER and ( $FREEZE or $THAW );;
+          if !$SERIALIZER and ( $FREEZE or $THAW );
         push @errors, "Cannot specify 'freeze', already using serializer '$serializer'"
           if $freeze;
         push @errors, "Cannot specify 'thaw', already using serializer '$serializer'"
@@ -135,7 +135,8 @@ sub import {
     if ( my @huh= keys %param ) {
         push @errors, "Don't know what to do with: @huh";
     }
-    die join "\n", "Found the following errors:", @errors if @errors;
+    die join "\n", "Found the following errors:", @errors
+      if @errors;
 
     # found specific serializer
     if ($serializer) {
@@ -177,7 +178,8 @@ sub _set_serializer {
       or push @errors, "$class does not provide a 'thaw' method";
 
     # huh?
-    die join "\n", "Found the following errors:", @errors if @errors;
+    die join "\n", "Found the following errors:", @errors
+      if @errors;
 
     # it's all ok
     $SERIALIZER= $class;
@@ -218,7 +220,7 @@ Thread::Queue::Any - thread-safe queues for any data-structure
 
 =head1 VERSION
 
-This documentation describes version 1.11.
+This documentation describes version 1.13.
 
 =head1 DESCRIPTION
 
@@ -379,6 +381,9 @@ systems like so:
 If your perl does not support the "blead" version of the code, then it will
 automatically install the "maint" version of the code.
 
+Please note that any additional parameters will simply be passed on to the
+underlying Makefile.PL processing.
+
 =head1 AUTHOR
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
